# Changelog

## [0.9.0](https://github.com/jbussdieker/bussdcc-device-manager/compare/v0.8.0...v0.9.0) (2026-03-26)


### Features

* **interface, dependencies:** move device management web interface to plugin ([80d52e4](https://github.com/jbussdieker/bussdcc-device-manager/commit/80d52e4540cc840cfeafa0b57504abf8d9b94fba))

## [0.8.0](https://github.com/jbussdieker/bussdcc-device-manager/compare/v0.7.0...v0.8.0) (2026-03-25)


### Features

* **config, interface:** refactor device management and settings handling ([7a055c1](https://github.com/jbussdieker/bussdcc-device-manager/commit/7a055c1c87c7c1748e524c09833e4ff989b41445))
* **interface, dependencies:** update dependencies and enhance device update flow ([567be0a](https://github.com/jbussdieker/bussdcc-device-manager/commit/567be0a35a511cb35c14364650c542cbb6434e70))
* **interface:** enhance settings update with form validation ([26a223f](https://github.com/jbussdieker/bussdcc-device-manager/commit/26a223f2ccb71ecfc058f556811d668ce2cc7dbe))
* **interface:** expand allowed endpoints for web interface ([12fa845](https://github.com/jbussdieker/bussdcc-device-manager/commit/12fa8451cd59e246549d8810055cad3fd1ba88a6))

## [0.7.0](https://github.com/jbussdieker/bussdcc-device-manager/compare/v0.6.0...v0.7.0) (2026-03-25)


### Features

* **dependencies, interface:** update bussdcc-system version and adjust template path ([a34123c](https://github.com/jbussdieker/bussdcc-device-manager/commit/a34123c3aa10179a3f131f624b39bd6238005c26))

## [0.6.0](https://github.com/jbussdieker/bussdcc-device-manager/compare/v0.5.0...v0.6.0) (2026-03-25)


### Features

* **dependencies:** update bussdcc-hardware version and optional dependencies ([d4be863](https://github.com/jbussdieker/bussdcc-device-manager/commit/d4be863198c0228e0e738ff25ba4962e7472ef61))
* **device_manager/web:** enhance device dependency visualization ([4c1a0b7](https://github.com/jbussdieker/bussdcc-device-manager/commit/4c1a0b78281f2fe03f3e0018dabf79f5f0d1ecf5))

## [0.5.0](https://github.com/jbussdieker/bussdcc-device-manager/compare/v0.4.0...v0.5.0) (2026-03-24)


### Features

* **device_manager:** enhance device update and dependency management ([918c7fb](https://github.com/jbussdieker/bussdcc-device-manager/commit/918c7fb3facc407f65ab12204bbc3219ed0c2e11))


### Bug Fixes

* **device_manager:** handle missing dependencies in graph calculation ([09f68bb](https://github.com/jbussdieker/bussdcc-device-manager/commit/09f68bb67550cd6f18285fbed9bcc9dbde2192bd))

## [0.4.0](https://github.com/jbussdieker/bussdcc-device-manager/compare/v0.3.0...v0.4.0) (2026-03-24)


### Features

* **device_manager:** enhance device management with new dependency handling ([6b8a87d](https://github.com/jbussdieker/bussdcc-device-manager/commit/6b8a87dad81432315734739732d9b3724672efc0))
* **device_manager:** remove bus management functionality ([5573e01](https://github.com/jbussdieker/bussdcc-device-manager/commit/5573e018055816aebb7e96a363ec1be249d21bf0))
* **device_manager:** update bussdcc-system dependency ([f8bef31](https://github.com/jbussdieker/bussdcc-device-manager/commit/f8bef315d183f8017bddfe8352ad9e434131fc66))

## [0.3.0](https://github.com/jbussdieker/bussdcc-device-manager/compare/v0.2.0...v0.3.0) (2026-03-23)


### Features

* **device_manager:** update dependencies and enhance client integration ([3d483d1](https://github.com/jbussdieker/bussdcc-device-manager/commit/3d483d16053b8ba3d40b609f28f1cdb465d5bdfe))

## [0.2.0](https://github.com/jbussdieker/bussdcc-device-manager/compare/v0.1.0...v0.2.0) (2026-03-23)


### Features

* **device_manager:** update hardware dependency and improve config loading ([9eb359d](https://github.com/jbussdieker/bussdcc-device-manager/commit/9eb359dde883b1b22db3da6c435286b0fc204115))

## 0.1.0 (2026-03-23)


### Features

* initial commit ([421446f](https://github.com/jbussdieker/bussdcc-device-manager/commit/421446fd1e7b41f8db5fe55b975570d6f3aedcd7))
